# m6anet
![alt text](https://github.com/GoekeLab/m6anet/blob/master/figures/m6anet_logo.png "m6anet")

m6anet is a python tool to detect m6a modifications from Nanopore Direct RNA Sequencing data

### Installation

m6anet requires [Python3](https://www.python.org). To install the latest release with PyPI (recommended) run

```sh
$ pip install m6anet
```

Alternatively, one can clone this repository and install via setup.py

```sh
$ git clone git@github.com:GoekeLab/m6anet.git
$ cd m6anet
$ python setup.py install
$ pip install -r requirements.txt 
```

See our documentation [here](https://m6anet.readthedocs.io/)!

### Getting help
We appreciate your feedback and questions! You can report any error or suggestion related to m6Anet as an issue on [github](https://github.com/GoekeLab/m6anet/issues). If you have questions related to the manuscript, data, or any general comment or suggestion please use the [Discussions](https://github.com/GoekeLab/m6anet/discussions).

Thank you!
### Citing m6Anet 

If you use m6Anet in your research, please use the following DOI for citation:

[![DOI](https://zenodo.org/badge/281866292.svg)](https://zenodo.org/badge/latestdoi/281866292)

Christopher Hendra, & Yuk Kei Wan. (2021, April 15). GoekeLab/m6anet: Pre-release (Version Pre-release). Zenodo. http://doi.org/10.5281/zenodo.4692776

### Contributors

This package is developed and maintaned by [Christopher Hendra](https://github.com/chrishendra93) and [Jonathan Göke](https://github.com/jonathangoeke). If you want to contribute, please leave an issue. Thank you.

### License
MIT

